/*
  This file is part of dolt.

  dolt is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  dolt is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with dolt; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  $Id: color.h,v 1.3 2003/05/27 16:06:03 beevek Exp $
*/

#ifndef _COLOR_H
#define _COLOR_H

#ifdef _WIN32
  // get rid of annoying stl warnings in MSVC++ about
  //  truncated debug symbols (because of long stl names)
  #pragma warning( disable : 4786 )
#endif // _WIN32

#include <map>
#include <iostream>
#include <string.h>

namespace dolt {


// defined in color.cpp (not part of the external interface)
class colorMap;

// rgba color class; default color is white
class Color
{
private:
  float red, green, blue, alpha;
  static colorMap colors;
public:
  Color( float r = 1.0, float g = 1.0, float b = 1.0, float a = 1.0 )
    : red(r), green(g), blue(b), alpha(a) {}

  // create a color by name from the color map; if no color with this
  // name exists, the default color is created (white)
  Color( const char *name );
  Color( const char *name, float a ); // set the alpha value too

  inline void setRGB( float r, float g, float b );
  inline void setAlpha( float a ) { alpha = a; }

  inline float r() const { return red; }
  inline float g() const { return green; }
  inline float b() const { return blue; }
  inline float a() const { return alpha; }

  // map this color to a name, e.g.
  // 
  //   Color red(1.0,0.0,0.0);
  //   red.nameColor( "red" );
  //
  // the name is inserted into the color map, and can then be used in
  // future constructors (e.g.  Color( "red" )).  if the name already
  // exists in the color map, its value is replaced.  names should not
  // begin with any of {1234567890.}
  void nameColor( const char *name );
};

// input operator; reads either a name (looked up in color map) or a
// set of three floats.  uses default alpha value.
std::istream & operator>>( std::istream &in, dolt::Color &c );

} // end namespace dolt

#endif // _COLOR_H
