/*
  This file is part of dolt.

  dolt is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  dolt is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with dolt; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  $Id: postscript.cpp,v 1.5 2003/05/13 22:27:42 beevek Exp $
*/

#include <fstream>
#include <dolt-lite.h>

using namespace dolt;

psFile::psFile( const char *file )
{
  open( file );
}

psFile::~psFile()
{
  if( is_open() )
    newpage();
  close();
}

bool psFile::open( const char *file )
{
  if( !file )
    return false;
  std::ofstream::open( file, std::ofstream::out | std::ofstream::trunc );
  if( fail() )
    return false;
  *this << "%!" << std::endl;  
  return true;
}

Point psFile::mapPoint( const Graphics &g, const Bbox &bounds,
  const double &scale, const Point &p )
{
  Point np(g.mapPoint( bounds, scale, p ));
  return Point(np.x() * 72,np.y() * 72);
}

void psFile::newpage()
{
  *this << "showpage" << std::endl;
}

void psFile::newpath()
{
  *this << "newpath" << std::endl;
}
